@@ -168,26 +168,12 @@ struct _VteTerminalPrivate {
         glong column_count;
 
 	/* Emulation setup data. */
-	struct _vte_termcap *termcap;	/* termcap storage */
 	struct _vte_matcher *matcher;	/* control sequence matcher */
 	const char *emulation;		/* terminal type to emulate */
-	struct vte_terminal_flags {	/* boolean termcap flags */
-		gboolean am;
-		gboolean bw;
-		gboolean LP;
-		gboolean ul;
-		gboolean xn;
-	} flags;
+        gboolean autowrap;              /* auto wraparound at right margin */
 	int keypad_mode, cursor_mode;	/* these would be VteKeymodes, but we
 					   need to guarantee its type */
-	gboolean sun_fkey_mode;
-	gboolean hp_fkey_mode;
-	gboolean legacy_fkey_mode;
-	gboolean vt220_fkey_mode;
-	int fkey;			/* this would be a VteFKey, but we
-					   need to guarantee its type */
 	GHashTable *dec_saved;
-	int default_column_count, default_row_count;	/* default sizes */
 
 	/* PTY handling data. */
 	VtePty *pty;
@@ -236,7 +222,6 @@ struct _VteTerminalPrivate {
 		gboolean sendrecv_mode;	/* sendrecv mode */
 		gboolean insert_mode;	/* insert mode */
 		gboolean linefeed_mode;	/* linefeed mode */
-		gboolean bracketed_paste_mode;
 		struct vte_scrolling_region {
 			int start, end;
 		} scrolling_region;	/* the region we scroll in */
@@ -254,9 +239,6 @@ struct _VteTerminalPrivate {
 					   fore/back with no
 					   character data */
 		gboolean alternate_charset;
-		gboolean status_line;
-		GString *status_line_contents;
-		gboolean status_line_changed;
 	} normal_screen, alternate_screen, *screen;
 
 	/* Selection information. */
@@ -292,6 +274,7 @@ struct _VteTerminalPrivate {
 	gboolean text_inserted_flag;
 	gboolean text_deleted_flag;
 	gboolean rewrap_on_resize;
+	gboolean bracketed_paste_mode;
 
 	/* Scrolling options. */
 	gboolean scroll_background;
@@ -449,7 +432,7 @@ void _vte_terminal_clear_tabstop(VteTerminal *terminal, int column);
 gboolean _vte_terminal_get_tabstop(VteTerminal *terminal, int column);
 void _vte_terminal_set_tabstop(VteTerminal *terminal, int column);
 void _vte_terminal_update_insert_delta(VteTerminal *terminal);
-void _vte_terminal_cleanup_tab_fragments_at_cursor (VteTerminal *terminal);
+void _vte_terminal_cleanup_fragments(VteTerminal *terminal, long start, long end);
 void _vte_terminal_audible_beep(VteTerminal *terminal);
 void _vte_terminal_visible_beep(VteTerminal *terminal);
 void _vte_terminal_beep(VteTerminal *terminal);
@@ -467,9 +450,9 @@ void _vte_terminal_ring_remove (VteTerminal *terminal, glong position);
 
 /* vteseq.c: */
 void _vte_terminal_handle_sequence(VteTerminal *terminal,
-				   const char *match_s,
-				   GQuark match,
+				   const char *match,
 				   GValueArray *params);
+
 gboolean _vte_terminal_xy_to_grid(VteTerminal *terminal,
                                   long x,
                                   long y,
