@@ -26,6 +26,7 @@
 #include <gio/gio.h>
 
 #include "vteenums.h"
+#include "vtemacros.h"
 
 G_BEGIN_DECLS
 
@@ -65,28 +66,25 @@ VtePty *vte_pty_new_foreign_sync (int fd,
                                   GCancellable *cancellable,
                                   GError **error);
 
-int vte_pty_get_fd (VtePty *pty);
+int vte_pty_get_fd (VtePty *pty) _VTE_GNUC_NONNULL(1);
 
-void vte_pty_close (VtePty *pty);
+void vte_pty_close (VtePty *pty) _VTE_GNUC_NONNULL(1);
 
-void vte_pty_child_setup (VtePty *pty);
+void vte_pty_child_setup (VtePty *pty) _VTE_GNUC_NONNULL(1);
 
 gboolean vte_pty_get_size (VtePty *pty,
                            int *rows,
                            int *columns,
-                           GError **error);
+                           GError **error) _VTE_GNUC_NONNULL(1);
 
 gboolean vte_pty_set_size (VtePty *pty,
                            int rows,
                            int columns,
-                           GError **error);
+                           GError **error) _VTE_GNUC_NONNULL(1);
 
 gboolean vte_pty_set_utf8 (VtePty *pty,
                            gboolean utf8,
-                           GError **error);
-
-void vte_pty_set_term (VtePty *pty,
-                       const char *emulation);
+                           GError **error) _VTE_GNUC_NONNULL(1);
 
 G_END_DECLS
 
